Task: MutualFriends
====================
Description: Task where two agents must discover which friend of theirs is mutual based on the friends's attributes. From He He et al. '17. 

Link: https://stanfordnlp.github.io/cocoa/

Tags: #MutualFriends, #All, #Goal

